diff --git a/Tools/PyUtils/bin/checkMetaSG.py b/Tools/PyUtils/bin/checkMetaSG.py
index 26211f16f569ec56499ab172afd3b7e0da0e1698..66e6e22f25989172733ea2eed4658704a09606bf 100755
--- a/Tools/PyUtils/bin/checkMetaSG.py
+++ b/Tools/PyUtils/bin/checkMetaSG.py
@@ -15,7 +15,6 @@
 
 from __future__ import print_function
 
-__version__ = "$Revision: 724150 $"
 __author__  = "Will Buttinger <will@cern.ch>"
 
 import sys
diff --git a/Tools/PyUtils/bin/checkTP.py b/Tools/PyUtils/bin/checkTP.py
index 325faa77b50f5c49c930b9da53fd83a345bdc03e..5494a43340ac8a5a72b63e85a86dd2fa105bc76b 100755
--- a/Tools/PyUtils/bin/checkTP.py
+++ b/Tools/PyUtils/bin/checkTP.py
@@ -20,7 +20,6 @@ from __future__ import print_function
 import sys
 import os
 
-__version__ = "$Revision: 1.3 $"
 __author__  = "Sebastien Binet"
 
 # MN: this has no effect when using RootType 
diff --git a/Tools/PyUtils/bin/checkxAOD.py b/Tools/PyUtils/bin/checkxAOD.py
index cd09a7b2865313846301b1913c62e00230eaa58f..c694d0a0bcd59f35ab836410a45c3de32c8f8af3 100755
--- a/Tools/PyUtils/bin/checkxAOD.py
+++ b/Tools/PyUtils/bin/checkxAOD.py
@@ -10,7 +10,6 @@
 
 from __future__ import print_function
 
-__version__ = "$Revision: 776263 $"
 __author__  = "Sebastien Binet <binet@cern.ch>, " \
     "Attila Krasznahorkay <Attila.Krasznahorkay@cern.ch>, " \
     "RD Schaffer R.D.Schaffer@cern.ch"
diff --git a/Tools/PyUtils/bin/diff-jobo-cfg.py b/Tools/PyUtils/bin/diff-jobo-cfg.py
index bd2d7009a02a955e2826fadc87c174dd06c71bec..8b6d464d6f6fbb546742636d13992eb68851e553 100755
--- a/Tools/PyUtils/bin/diff-jobo-cfg.py
+++ b/Tools/PyUtils/bin/diff-jobo-cfg.py
@@ -16,7 +16,6 @@
 
 from __future__ import print_function
 
-__version__ = "$Revision: 298860 $"
 __author__  = "Sebastien Binet, Adrien Renaud"
 
 import sys
diff --git a/Tools/PyUtils/bin/filter-and-merge-d3pd.py b/Tools/PyUtils/bin/filter-and-merge-d3pd.py
index f53ff2638255d37b2d047f9a559b48df7f8a9c74..6cae1e2dfa6c05da86e73ce202f2655eda7acce9 100755
--- a/Tools/PyUtils/bin/filter-and-merge-d3pd.py
+++ b/Tools/PyUtils/bin/filter-and-merge-d3pd.py
@@ -747,7 +747,6 @@ Accepted command line options:
 # @author http://code.activestate.com/recipes/573463
 #         slightly adapted to follow PEP8 conventions
 
-__version__ = "$Revision: 547442 $"
 __doc__ = """\
 functions to convert an XML file into a python dict, back and forth
 """
diff --git a/Tools/PyUtils/bin/print_auditor_callgraph.py b/Tools/PyUtils/bin/print_auditor_callgraph.py
index e3bf1cc952c81286fe11e5750ef14723ac845b99..5d4c72751b17bf1f475ac35305ea769fd28f7cf5 100755
--- a/Tools/PyUtils/bin/print_auditor_callgraph.py
+++ b/Tools/PyUtils/bin/print_auditor_callgraph.py
@@ -16,7 +16,6 @@
 
 from __future__ import print_function
 
-__version__ = "$Revision: 1.1 $"
 __author__  = "Sebastien Binet <binet@cern.ch>"
 
 import os
@@ -30,11 +29,11 @@ class Steps:
     ALLOWED = ('ini', 'exe', 'fin')
     
 def parse_log_file(fname, step=Steps.ini):
-    beg_pat = re.compile(r"NameAuditor.*?About to Enter "\
-                         r"(?P<CompName>.*?) "\
+    beg_pat = re.compile(r"NameAuditor.*?About to Enter "
+                         r"(?P<CompName>.*?) "
                          r"%s Method"%step)
-    end_pat = re.compile(r"NameAuditor.*?Just Exited "\
-                         r"(?P<CompName>.*?) "\
+    end_pat = re.compile(r"NameAuditor.*?Just Exited "
+                         r"(?P<CompName>.*?) "
                          r"%s Method"%step)
 
     stack = 0
diff --git a/Tools/PyUtils/python/Logging.py b/Tools/PyUtils/python/Logging.py
index 5459479b4db34a8e5bff7a9841073fb256fa4271..4646514d31405ff40a4a7a12e762962efa6edaa5 100644
--- a/Tools/PyUtils/python/Logging.py
+++ b/Tools/PyUtils/python/Logging.py
@@ -5,7 +5,6 @@
 ## @purpose: try to import Logging from AthenaCommon.
 ##           falls back on stdlib's one
 
-__version__ = "$Revision$"
 __author__  = "Sebastien Binet"
 
 __all__ = ['msg', 'logging']
diff --git a/Tools/PyUtils/python/scripts/cmake_depends.py b/Tools/PyUtils/python/scripts/cmake_depends.py
index b0ab8de345e6727afe86b2971639be0f6bdeca8d..d598e41b096673e750b9273d4b22bfc09d70b2b6 100644
--- a/Tools/PyUtils/python/scripts/cmake_depends.py
+++ b/Tools/PyUtils/python/scripts/cmake_depends.py
@@ -186,6 +186,7 @@ class AthGraph:
 @acmdlib.argument('--cmakedot', help=argparse.SUPPRESS)
 
 def main(args):
+   """Inspect cmake build dependencies"""
 
    # Find packages.dot:
    if not args.cmakedot:
diff --git a/Tools/PyUtils/python/scripts/filter_files.py b/Tools/PyUtils/python/scripts/filter_files.py
index 4c93e976cb0d92708209a647f045af2fb1cf74c9..207a731a4aeafd9abc10cd32bf7c453ade6b95ee 100644
--- a/Tools/PyUtils/python/scripts/filter_files.py
+++ b/Tools/PyUtils/python/scripts/filter_files.py
@@ -7,7 +7,7 @@
 # @date March 2010
 from __future__ import with_statement
 
-__doc__ = "take a bunch of input (pool/bs) files and produce a filtered one"
+__doc__ = "filter multiple input (pool/bs) files"
 __author__ = "Sebastien Binet"
 
 
@@ -33,8 +33,8 @@ import PyUtils.acmdlib as acmdlib
     help='comma separated list of tuples (run,event) numbers to select or an ascii file containg a list of such run+event numbers to select'
     )
 def main(args):
-    """take a bunch of input (pool/bs) files and produce a filtered one
-    """
+    """filter multiple input (pool/bs) files"""
+
     exitcode = 0
 
     import PyUtils.Logging as L
diff --git a/Tools/PyUtils/python/scripts/merge_files.py b/Tools/PyUtils/python/scripts/merge_files.py
index b87db3b1ac584d13aac3741bb9e08852cfbe07a8..58a6ebed1a0987b0445fb1860e9833f4e8916545 100644
--- a/Tools/PyUtils/python/scripts/merge_files.py
+++ b/Tools/PyUtils/python/scripts/merge_files.py
@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+# Copyright (C) 2002-2020 CERN for the benefit of the ATLAS collaboration
 
 # @file PyUtils.scripts.merge_files
 # @purpose take a bunch of input (pool/bs) files and produce a single one
@@ -6,8 +6,7 @@
 # @author Sebastien Binet
 # @date February 2010
 
-__version__ = "$Revision: 310812 $"
-__doc__ = "take a bunch of input (pool/bs) files and produce a single one"
+__doc__ = "merge multiple input (pool/bs) files"
 __author__ = "Sebastien Binet"
 
 
@@ -39,8 +38,8 @@ import PyUtils.acmdlib as acmdlib
     help = "Path to a file where to put athena job's logfile"
     )
 def main(args):
-    """take a bunch of input (pool/bs) files and produce a single one
-    """
+    """merge multiple input (pool/bs) files"""
+
     exitcode = 0
 
     import PyUtils.Logging as L
@@ -48,7 +47,6 @@ def main(args):
     msg.setLevel(L.logging.INFO)
 
     msg.info(':'*40)
-    msg.info('welcome to merge-files version %s', __version__)
 
     import os.path as osp
     args.files = [ osp.expandvars(osp.expanduser(fname))
diff --git a/Tools/PyUtils/python/scripts/diff_pool_files.py b/Tools/PyUtils/python/scripts/diff_pool_files.py
index 5f9de6453525f9689e00439371295e4008192019..90db00dbcd32425354efed1faa01e76fe5bc992e 100644
--- a/Tools/PyUtils/python/scripts/diff_pool_files.py
+++ b/Tools/PyUtils/python/scripts/diff_pool_files.py
@@ -1,12 +1,11 @@
-# Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+# Copyright (C) 2002-2020 CERN for the benefit of the ATLAS collaboration
 
 # @file PyUtils.scripts.diff_pool_files
 # @purpose check that 2 POOL files have same content (containers and sizes).
 # @author Sebastien Binet
 # @date February 2010
 
-__version__ = "$Revision: 276362 $"
-__doc__ = "check that 2 POOL files have same content (containers and sizes)."
+__doc__ = "diff two POOL files (containers and sizes)"
 __author__ = "Sebastien Binet"
 
 
@@ -23,8 +22,7 @@ import PyUtils.acmdlib as acmdlib
                   default=False,
                   help="""Enable verbose printout""")
 def main(args):
     """check that 2 POOL files have same content (containers and sizes)
     """
 
     import os.path as osp
     old = osp.expandvars(osp.expanduser(args.old))
@@ -23,8 +22,7 @@ import PyUtils.acmdlib as acmdlib
                   help="""Enable verbose printout""")
 def main(args):
-    """check that 2 POOL files have same content (containers and sizes)
-    """
+    """diff two POOL files (containers and sizes)"""
 
     import os.path as osp
diff --git a/Tools/PyUtils/python/scripts/diff_root_files.py b/Tools/PyUtils/python/scripts/diff_root_files.py
index 33797a6742ef18152bc474520889721536c11626..f5c785f992ec91d92df8c74e1f9765484796dbe5 100644
--- a/Tools/PyUtils/python/scripts/diff_root_files.py
+++ b/Tools/PyUtils/python/scripts/diff_root_files.py
@@ -5,7 +5,7 @@
 # @author Sebastien Binet
 # @date February 2010
 
-__doc__ = "check that 2 ROOT files have same content (containers and sizes)."
+__doc__ = "diff two ROOT files (containers and sizes)"
 __author__ = "Sebastien Binet"
 
 ### imports -------------------------------------------------------------------
@@ -96,8 +96,8 @@ allowed: %(choices)s
                   help="""Compare nan as equal to nan""")
 
 def main(args):
-    """check that 2 ROOT files have same content (containers and sizes)
-    """
+    """diff two ROOT files (containers and sizes)"""
+
     global g_args
     g_args = args
     